@@ -12,6 +12,6 @@
 
 grass_fuel_moisture_code <- function(MC0) {
   # Eq. 12 - Calculate GFMC
-  GFMC0 <- 59.5 * ((250 - MC0) / (147.27723 + MC0))
+  GFMC0 <- 59.5 * ((250 - MC0) / (FFMC_COEFFICIENT + MC0))
   return(GFMC0)
 }
